==> qore-0.8.11.tar.bz2: qore-0.8.11/docs/lang/html/search/all_78.js <==
var searchData=
[
  ['x509_5fv_5ferr_5fakid_5fissuer_5fserial_5fmismatch',['X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH',['../group__x509__verification__constants.html#ga0d28ad9c54f79922715013bca49f4a52',1,'Qore']]],
  ['x509_5fv_5ferr_5fakid_5fskid_5fmismatch',['X509_V_ERR_AKID_SKID_MISMATCH',['../group__x509__verification__constants.html#gaea4002870f0a1df88999dfc925243b95',1,'Qore']]],
  ['x509_5fv_5ferr_5fapplication_5fverification',['X509_V_ERR_APPLICATION_VERIFICATION',['../group__x509__verification__constants.html#ga2f48578acd358ebfe55100f6daf1602b',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fchain_5ftoo_5flong',['X509_V_ERR_CERT_CHAIN_TOO_LONG',['../group__x509__verification__constants.html#ga78a4220220d45411835ef8601b8294bb',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fhas_5fexpired',['X509_V_ERR_CERT_HAS_EXPIRED',['../group__x509__verification__constants.html#gae6407bd35520f45e29800b396e7e7dc2',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fnot_5fyet_5fvalid',['X509_V_ERR_CERT_NOT_YET_VALID',['../group__x509__verification__constants.html#gadd182b1dd774f8c4181f9147991afb3a',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5frejected',['X509_V_ERR_CERT_REJECTED',['../group__x509__verification__constants.html#ga04e25fb5ed66b37b280758ed17cce0f9',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5frevoked',['X509_V_ERR_CERT_REVOKED',['../group__x509__verification__constants.html#gaaab55b073ffb0af920c408a7c6c18bc3',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fsignature_5ffailure',['X509_V_ERR_CERT_SIGNATURE_FAILURE',['../group__x509__verification__constants.html#ga0194c30188610d8aef7df4a98d2583ba',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5funtrusted',['X509_V_ERR_CERT_UNTRUSTED',['../group__x509__verification__constants.html#gad8effb53d699713577403dbd93d18940',1,'Qore']]],
  ['x509_5fv_5ferr_5fcrl_5fhas_5fexpired',['X509_V_ERR_CRL_HAS_EXPIRED',['../group__x509__verification__constants.html#gace0346e494d1793f0524bcd534f43f7f',1,'Qore']]],
  ['x509_5fv_5ferr_5fcrl_5fnot_5fyet_5fvalid',['X509_V_ERR_CRL_NOT_YET_VALID',['../group__x509__verification__constants.html#ga757330b3e07026d87148774bd15eefa4',1,'Qore']]],
  ['x509_5fv_5ferr_5fcrl_5fsignature_5ffailure',['X509_V_ERR_CRL_SIGNATURE_FAILURE',['../group__x509__verification__constants.html#gaf5306ef80a14597259e706c143b41796',1,'Qore']]],
  ['x509_5fv_5ferr_5fdepth_5fzero_5fself_5fsigned_5fcert',['X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT',['../group__x509__verification__constants.html#ga345ab69e53100f9349d9a38877bb44ca',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcert_5fnot_5fafter_5ffield',['X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD',['../group__x509__verification__constants.html#gadde3ff8cecf56d2ef5473bc279e8910c',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcert_5fnot_5fbefore_5ffield',['X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD',['../group__x509__verification__constants.html#ga1c827ab82254df93dfc83b22d764dba6',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcrl_5flast_5fupdate_5ffield',['X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD',['../group__x509__verification__constants.html#gaa6c7200e8827c8664172575c70683754',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcrl_5fnext_5fupdate_5ffield',['X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD',['../group__x509__verification__constants.html#gaa00c30bf61fbe3924d06c96c3d20e7d9',1,'Qore']]],
  ['x509_5fv_5ferr_5finvalid_5fca',['X509_V_ERR_INVALID_CA',['../group__x509__verification__constants.html#gab638296ef4610b30d0660fa13e045954',1,'Qore']]],
  ['x509_5fv_5ferr_5finvalid_5fpurpose',['X509_V_ERR_INVALID_PURPOSE',['../group__x509__verification__constants.html#ga236bc06dac524bcb9a61180e568bc462',1,'Qore']]],
  ['x509_5fv_5ferr_5fkeyusage_5fno_5fcertsign',['X509_V_ERR_KEYUSAGE_NO_CERTSIGN',['../group__x509__verification__constants.html#ga2163d9e78be7ed6ffdd8d1e9ae5c1331',1,'Qore']]],
  ['x509_5fv_5ferr_5fout_5fof_5fmem',['X509_V_ERR_OUT_OF_MEM',['../group__x509__verification__constants.html#gac1ace11411b4a1bfd915c2322d04136e',1,'Qore']]],
  ['x509_5fv_5ferr_5fpath_5flength_5fexceeded',['X509_V_ERR_PATH_LENGTH_EXCEEDED',['../group__x509__verification__constants.html#ga1e7f2975f18582ef16903119a9c932d5',1,'Qore']]],
  ['x509_5fv_5ferr_5fself_5fsigned_5fcert_5fin_5fchain',['X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN',['../group__x509__verification__constants.html#gaf1c08de19215f3800a41504bda25c20d',1,'Qore']]],
  ['x509_5fv_5ferr_5fsubject_5fissuer_5fmismatch',['X509_V_ERR_SUBJECT_ISSUER_MISMATCH',['../group__x509__verification__constants.html#gaad87fc6ed5543a647eccdae0a98349d8',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fdecode_5fissuer_5fpublic_5fkey',['X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY',['../group__x509__verification__constants.html#ga88ea09360717cf145bdd190c3e132c7d',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fdecrypt_5fcert_5fsignature',['X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE',['../group__x509__verification__constants.html#ga4a67994a701467704c8900ec6b0a42c6',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fdecrypt_5fcrl_5fsignature',['X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE',['../group__x509__verification__constants.html#gae1e5481186ecefe9b89d5e2387084fb1',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fget_5fcrl',['X509_V_ERR_UNABLE_TO_GET_CRL',['../group__x509__verification__constants.html#ga54fe67c0c13ae6dfeb20ea2f197be267',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fget_5fissuer_5fcert',['X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT',['../group__x509__verification__constants.html#gac348670d2763dc7bce25889c1c9694ec',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fget_5fissuer_5fcert_5flocally',['X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY',['../group__x509__verification__constants.html#ga7f6fe4a2dd47539540e2919e464e528d',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fverify_5fleaf_5fsignature',['X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE',['../group__x509__verification__constants.html#ga86aaa114c74aab441847ad4db7597a6f',1,'Qore']]],
  ['x509_5fv_5fok',['X509_V_OK',['../group__x509__verification__constants.html#ga5ef6a3725dcb9fff52ac9fabda19469b',1,'Qore']]],
  ['x_2e509_20verification_20constants',['X.509 Verification Constants',['../group__x509__verification__constants.html',1,'']]],
  ['x509_5fverificationreasons',['X509_VerificationReasons',['../group__x509__verification__constants.html#ga0ebd0784741e7d3521e972da7f294aba',1,'Qore']]],
  ['xrange',['xrange',['../group__range__functions.html#ga6eabf589db52e9febb178cdb5e66ec4c',1,'Qore::xrange(int start, int stop, int step=1)'],['../group__range__functions.html#ga85798861f6ac3dc0adafaa8db337d8e5',1,'Qore::xrange(int stop)']]]
];

==> qore-0.8.13.5.tar.bz2: qore-0.8.13.5/docs/lang/html/search/all_78.js <==
var searchData=
[
  ['x509_5fv_5ferr_5fakid_5fissuer_5fserial_5fmismatch',['X509_V_ERR_AKID_ISSUER_SERIAL_MISMATCH',['../group__x509__verification__constants.html#ga0d28ad9c54f79922715013bca49f4a52',1,'Qore']]],
  ['x509_5fv_5ferr_5fakid_5fskid_5fmismatch',['X509_V_ERR_AKID_SKID_MISMATCH',['../group__x509__verification__constants.html#gaea4002870f0a1df88999dfc925243b95',1,'Qore']]],
  ['x509_5fv_5ferr_5fapplication_5fverification',['X509_V_ERR_APPLICATION_VERIFICATION',['../group__x509__verification__constants.html#ga2f48578acd358ebfe55100f6daf1602b',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fchain_5ftoo_5flong',['X509_V_ERR_CERT_CHAIN_TOO_LONG',['../group__x509__verification__constants.html#ga78a4220220d45411835ef8601b8294bb',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fhas_5fexpired',['X509_V_ERR_CERT_HAS_EXPIRED',['../group__x509__verification__constants.html#gae6407bd35520f45e29800b396e7e7dc2',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fnot_5fyet_5fvalid',['X509_V_ERR_CERT_NOT_YET_VALID',['../group__x509__verification__constants.html#gadd182b1dd774f8c4181f9147991afb3a',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5frejected',['X509_V_ERR_CERT_REJECTED',['../group__x509__verification__constants.html#ga04e25fb5ed66b37b280758ed17cce0f9',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5frevoked',['X509_V_ERR_CERT_REVOKED',['../group__x509__verification__constants.html#gaaab55b073ffb0af920c408a7c6c18bc3',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5fsignature_5ffailure',['X509_V_ERR_CERT_SIGNATURE_FAILURE',['../group__x509__verification__constants.html#ga0194c30188610d8aef7df4a98d2583ba',1,'Qore']]],
  ['x509_5fv_5ferr_5fcert_5funtrusted',['X509_V_ERR_CERT_UNTRUSTED',['../group__x509__verification__constants.html#gad8effb53d699713577403dbd93d18940',1,'Qore']]],
  ['x509_5fv_5ferr_5fcrl_5fhas_5fexpired',['X509_V_ERR_CRL_HAS_EXPIRED',['../group__x509__verification__constants.html#gace0346e494d1793f0524bcd534f43f7f',1,'Qore']]],
  ['x509_5fv_5ferr_5fcrl_5fnot_5fyet_5fvalid',['X509_V_ERR_CRL_NOT_YET_VALID',['../group__x509__verification__constants.html#ga757330b3e07026d87148774bd15eefa4',1,'Qore']]],
  ['x509_5fv_5ferr_5fcrl_5fsignature_5ffailure',['X509_V_ERR_CRL_SIGNATURE_FAILURE',['../group__x509__verification__constants.html#gaf5306ef80a14597259e706c143b41796',1,'Qore']]],
  ['x509_5fv_5ferr_5fdepth_5fzero_5fself_5fsigned_5fcert',['X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT',['../group__x509__verification__constants.html#ga345ab69e53100f9349d9a38877bb44ca',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcert_5fnot_5fafter_5ffield',['X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD',['../group__x509__verification__constants.html#gadde3ff8cecf56d2ef5473bc279e8910c',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcert_5fnot_5fbefore_5ffield',['X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD',['../group__x509__verification__constants.html#ga1c827ab82254df93dfc83b22d764dba6',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcrl_5flast_5fupdate_5ffield',['X509_V_ERR_ERROR_IN_CRL_LAST_UPDATE_FIELD',['../group__x509__verification__constants.html#gaa6c7200e8827c8664172575c70683754',1,'Qore']]],
  ['x509_5fv_5ferr_5ferror_5fin_5fcrl_5fnext_5fupdate_5ffield',['X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD',['../group__x509__verification__constants.html#gaa00c30bf61fbe3924d06c96c3d20e7d9',1,'Qore']]],
  ['x509_5fv_5ferr_5finvalid_5fca',['X509_V_ERR_INVALID_CA',['../group__x509__verification__constants.html#gab638296ef4610b30d0660fa13e045954',1,'Qore']]],
  ['x509_5fv_5ferr_5finvalid_5fpurpose',['X509_V_ERR_INVALID_PURPOSE',['../group__x509__verification__constants.html#ga236bc06dac524bcb9a61180e568bc462',1,'Qore']]],
  ['x509_5fv_5ferr_5fkeyusage_5fno_5fcertsign',['X509_V_ERR_KEYUSAGE_NO_CERTSIGN',['../group__x509__verification__constants.html#ga2163d9e78be7ed6ffdd8d1e9ae5c1331',1,'Qore']]],
  ['x509_5fv_5ferr_5fout_5fof_5fmem',['X509_V_ERR_OUT_OF_MEM',['../group__x509__verification__constants.html#gac1ace11411b4a1bfd915c2322d04136e',1,'Qore']]],
  ['x509_5fv_5ferr_5fpath_5flength_5fexceeded',['X509_V_ERR_PATH_LENGTH_EXCEEDED',['../group__x509__verification__constants.html#ga1e7f2975f18582ef16903119a9c932d5',1,'Qore']]],
  ['x509_5fv_5ferr_5fself_5fsigned_5fcert_5fin_5fchain',['X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN',['../group__x509__verification__constants.html#gaf1c08de19215f3800a41504bda25c20d',1,'Qore']]],
  ['x509_5fv_5ferr_5fsubject_5fissuer_5fmismatch',['X509_V_ERR_SUBJECT_ISSUER_MISMATCH',['../group__x509__verification__constants.html#gaad87fc6ed5543a647eccdae0a98349d8',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fdecode_5fissuer_5fpublic_5fkey',['X509_V_ERR_UNABLE_TO_DECODE_ISSUER_PUBLIC_KEY',['../group__x509__verification__constants.html#ga88ea09360717cf145bdd190c3e132c7d',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fdecrypt_5fcert_5fsignature',['X509_V_ERR_UNABLE_TO_DECRYPT_CERT_SIGNATURE',['../group__x509__verification__constants.html#ga4a67994a701467704c8900ec6b0a42c6',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fdecrypt_5fcrl_5fsignature',['X509_V_ERR_UNABLE_TO_DECRYPT_CRL_SIGNATURE',['../group__x509__verification__constants.html#gae1e5481186ecefe9b89d5e2387084fb1',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fget_5fcrl',['X509_V_ERR_UNABLE_TO_GET_CRL',['../group__x509__verification__constants.html#ga54fe67c0c13ae6dfeb20ea2f197be267',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fget_5fissuer_5fcert',['X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT',['../group__x509__verification__constants.html#gac348670d2763dc7bce25889c1c9694ec',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fget_5fissuer_5fcert_5flocally',['X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY',['../group__x509__verification__constants.html#ga7f6fe4a2dd47539540e2919e464e528d',1,'Qore']]],
  ['x509_5fv_5ferr_5funable_5fto_5fverify_5fleaf_5fsignature',['X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE',['../group__x509__verification__constants.html#ga86aaa114c74aab441847ad4db7597a6f',1,'Qore']]],
  ['x509_5fv_5fok',['X509_V_OK',['../group__x509__verification__constants.html#ga5ef6a3725dcb9fff52ac9fabda19469b',1,'Qore']]],
  ['x_2e509_20verification_20constants',['X.509 Verification Constants',['../group__x509__verification__constants.html',1,'']]],
  ['x509_5fverificationreasons',['X509_VerificationReasons',['../group__x509__verification__constants.html#ga0ebd0784741e7d3521e972da7f294aba',1,'Qore']]],
  ['xrange',['xrange',['../group__range__functions.html#gad5b4d3ad3f6c36d2e714bc6ed757a507',1,'Qore::xrange(int start, int stop, int step=1, auto val)'],['../group__range__functions.html#ga85798861f6ac3dc0adafaa8db337d8e5',1,'Qore::xrange(int stop)']]]
];
